@@ -14,7 +14,7 @@ from .pacman_i18n import _p
 from .core import DataType, PackageSource
 from .version import VersionMatcher
 from .pprint import print_stderr, color_enabled, color_line
-from .args import parse_args, reconstruct_args
+from .args import parse_args, reconstruct_args, PACMAN_STR_OPTS, PACMAN_APPEND_OPTS
 from .config import PikaurConfig
 from .exceptions import PackagesNotFoundInRepo, DependencyError
 from .core import sudo, spawn
@@ -67,32 +67,22 @@ def get_pacman_command(ignore_args: Optional[List[str]] = None) -> List[str]:
     else:
         pacman_cmd += ['--color=never']
 
-    for arg in [
-            'dbpath',
-            'root',
-            'arch',
-            'cachedir',
-            'config',
-            'gpgdir',
-            'hookdir',
-            'logfile',
-            'print_format',
-    ]:
+    for _short, arg, _default in PACMAN_STR_OPTS:
+        if arg in ['color', ]:  # we force it anyway
+            continue
         if arg in ignore_args:
             continue
         value = getattr(args, arg)
         if value:
-            pacman_cmd += ['--' + arg.replace('_', '-'), value]
+            pacman_cmd += ['--' + arg, value]
 
-    for arg in [
-            'overwrite',
-            'assume_installed',
-            'ignoregroup',
-    ]:
+    for _short, arg, _default in PACMAN_APPEND_OPTS:
+        if arg in ['ignore', ]:  # we reprocess it anyway
+            continue
         if arg in ignore_args:
             continue
         for value in getattr(args, arg) or []:
-            pacman_cmd += ['--' + arg.replace('_', '-'), value]
+            pacman_cmd += ['--' + arg, value]
 
     return pacman_cmd
 
@@ -536,11 +526,19 @@ def find_upgradeable_packages() -> List[pyalpm.Package]:
     ]
 
 
-def find_sysupgrade_packages() -> List[pyalpm.Package]:
+def find_sysupgrade_packages(ignore_pkgs: Optional[List[str]] = None) -> List[pyalpm.Package]:
     all_repo_pkgs = PackageDB.get_repo_dict()
 
+    extra_args: List[str] = []
+    for excluded_pkg_name in ignore_pkgs or []:
+        extra_args.append('--ignore')
+        # pacman's --ignore doesn't work with repo name:
+        extra_args.append(strip_repo_name(excluded_pkg_name))
+
     results = PackageDB.get_print_format_output(
-        get_pacman_command() + ['--sync'] + ['--sysupgrade'] * parse_args().sysupgrade
+        get_pacman_command() + ['--sync'] +
+        ['--sysupgrade'] * parse_args().sysupgrade +
+        extra_args
     )
     return [
         all_repo_pkgs[result.full_name] for result in results
